#Import classes from cards
from scrython.cards import Autocomplete
from scrython.cards import Collector
from scrython.cards import Id
from scrython.cards import Mtgo
from scrython.cards import Multiverse
from scrython.cards import Named
from scrython.cards import Random

#Import classes from rulings
from scrython.rulings import Mtgo
from scrython.rulings import Multiverse
from scrython.rulings import Id
from scrython.rulings import Code
